unit gfx_resizectrl;
{***********************************************************************
Unit gfx_resizeCtrl.PAS v1.0
    (c) by Andreas Moser, amoser@amoser.de,

    Delphi version : Delphi 4

    gfx_resizectrl is part of the gfx_library collection

    You may use this sourcecode for your freewareproducts.
    You may modify this source-code for your own use.
    You may recompile this source-code for your own use.

    All functions, procedures and classes may NOT be used in commercial
    products without the permission of the author. For parts of this library
    which are not written by me, you have to ask for permission by their
    respective authors.


    Disclaimer of warranty: "This software is supplied as is. The author
    disclaims all warranties, expressed or implied, including, without
    limitation, the warranties of merchantability and of fitness for any
    purpose. The author assumes no liability for damages, direct or
    consequential, which may result from the use of this software."

    All brand and product names are marks or registered marks of their
    respective companies.

    Please report bugs to:
    Andreas Moser  amoser@amoser.de

********************************************************************************}
interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Buttons,gfx_basedef,gfx_rotresize,vcl_tools;

type
  TResizeCtrlForm = class(TForm)
    GroupBox1: TGroupBox;
    ActWidEdit: TEdit;
    ActHeiEdit: TEdit;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    GroupBox2: TGroupBox;
    Label4: TLabel;
    Label5: TLabel;
    Label6: TLabel;
    ActHPercEdit: TEdit;
    ActVPercEdit: TEdit;
    GroupBox3: TGroupBox;
    TypeCombo: TComboBox;
    BitBtn1: TBitBtn;
    BitBtn2: TBitBtn;
    SynchronCheck: TCheckBox;
    Label7: TLabel;
    RatioEdit: TEdit;
    RatioCheckBox: TCheckBox;
    procedure FormCreate(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure BitBtn1Click(Sender: TObject);
    procedure ActWidEditKeyUp(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure ActHeiEditKeyUp(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure ActVPercEditKeyUp(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure ActHPercEditKeyUp(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure RatioEditKeyUp(Sender: TObject; var Key: Word;
      Shift: TShiftState);
  private
    { Private-Deklarationen }
    procedure ActualizeValues;
  public
    FOrgWidth:Integer;
    FOrgHeight:Integer;
    FWidth:Integer;
    FHeight:Integer;
    FHPercent:Integer;
    FVPercent:Integer;
    FSrcBitmap:TBitmap;
    FDestBitmap:TBitmap;
    FRatio:Double;
    { Public-Deklarationen }
  end;

var
  ResizeCtrlForm: TResizeCtrlForm;

implementation

{$R *.DFM}



procedure TResizeCtrlForm.FormCreate(Sender: TObject);
begin
  TypeCombo.ItemIndex:=6;
  FDestBitmap:=TBitmap.Create;
  FDestBitmap.PixelFormat:=pf24Bit;
  FSrcBitmap:=TBitmap.Create;
  FSrcBitmap.PixelFormat:=pf24Bit;
end;

procedure TResizeCtrlForm.FormShow(Sender: TObject);
begin
   if not Assigned(FSrcBitmap) then
   begin
     EGraphicConvert.Create('Internal Error. Bitmap not assigned');
     Close;
   end else
   begin
      if FSrcBitmap.PixelFormat<>pf24Bit then FSrcBitmap.Pixelformat:=pf24bit;
      FOrgWidth:=FSrcBitmap.Width;
      FOrgHeight:=FSrcBitmap.Height;
      FWidth:=FOrgWidth;
      FHeight:=FOrgHeight;
      FHPercent:=100;
      FVPercent:=100;
      FRatio:=FSrcBitmap.Width / FSrcBitmap.Height;
      ActualizeValues;
   end;
end;

procedure TResizeCtrlForm.ActualizeValues;
begin
      ActHPercEdit.Text:=IntToStr(FHPercent);
      ActVPercEdit.Text:=IntToStr(FVPercent);
      ActWidEdit.Text:=IntToStr(FWidth);
      ActHeiEdit.Text:=IntToStr(FHeight);
      RatioEdit.Text:=FloatToStr(FRatio);
end;

procedure TResizeCtrlForm.BitBtn1Click(Sender: TObject);
begin
  Screen.Cursor:=crHourGlass;
  CreateXPanel(Self,200,100);
  XPanel.Caption:='Resampling...';
 try
  case TypeCombo.ItemIndex of

  0:  Resample(FSrcBitmap,FDestBitmap,FWidth,Fheight,SplineFilter,3,XProgress);
  1:  Resample(FSrcBitmap,FDestBitmap,FWidth,Fheight,BellFilter,3,XProgress);
  2:  Resample(FSrcBitmap,FDestBitmap,FWidth,Fheight,TriangleFilter,3,XProgress);
  3:  Resample(FSrcBitmap,FDestBitmap,FWidth,Fheight,BoxFilter,3,XProgress);
  4:  Resample(FSrcBitmap,FDestBitmap,FWidth,Fheight,HermiteFilter,3,XProgress);
  5:  Resample(FSrcBitmap,FDestBitmap,FWidth,Fheight,Lanczos3Filter,3,XProgress);
  6:  Resample(FSrcBitmap,FDestBitmap,FWidth,Fheight,MitchellFilter,3,XProgress);
  end;
 finally
  ReleaseXPanel;
  Screen.Cursor:=crDefault;
 end;
end;

procedure TResizeCtrlForm.ActWidEditKeyUp(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  if (Sender as TEdit).Text<>'' then
  begin
    FWidth:=StrToInt(ActWidEdit.Text);
    if RatioCheckBox.Checked then
    begin
      FHeight:=Round(FWidth / FRatio);
    end;
      FHPercent:=round(FWidth / (FOrgWidth / 100));
      FVPercent:=round(FHeight / (FOrgHeight / 100));
      ActualizeValues;
  end;

end;

procedure TResizeCtrlForm.ActHeiEditKeyUp(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  if (Sender as TEdit).Text<>'' then
  begin
    FHeight:=StrToInt(ActHeiEdit.Text);
    if RatioCheckBox.Checked then
    begin
      FWidth:=Round(FHeight*FRatio);
    end;
      FHPercent:=round(FWidth / (FOrgWidth / 100));
      FVPercent:=round(FHeight / (FOrgHeight / 100));
      ActualizeValues;
  end;
end;

procedure TResizeCtrlForm.ActVPercEditKeyUp(Sender: TObject;
  var Key: Word; Shift: TShiftState);
begin
  if (Sender as TEdit).Text<>'' then
  begin
    FVPercent:=StrToInt(ActVPercEdit.Text);
    if SynchronCheck.Checked then
    begin
      FHpercent:=FVPercent;
    end;
      FWidth:=Round((FOrgWidth / 100)*FHPercent);
      Fheight:=Round((FOrgHeight / 100)*FVPercent);
      ActualizeValues;
  end;
end;

procedure TResizeCtrlForm.ActHPercEditKeyUp(Sender: TObject;
  var Key: Word; Shift: TShiftState);
begin
  if (Sender as TEdit).Text<>'' then
  begin
    FHPercent:=StrToInt(ActHPercEdit.Text);
    if SynchronCheck.Checked then
    begin
      FVpercent:=FHPercent;
    end;
      FWidth:=Round((FOrgWidth / 100)*FHPercent);
      Fheight:=Round((FOrgHeight / 100)*FVPercent);
      ActualizeValues;
  end;

end;

procedure TResizeCtrlForm.RatioEditKeyUp(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  if (Sender as TEdit).Text<>'' then
  FRatio:=StrToFloat(RatioEdit.Text);
  FHeight:=Round(FWidth / FRatio);
  FHPercent:=round(FWidth / (FOrgWidth / 100));
  FVPercent:=round(FHeight / (FOrgHeight / 100));

  ActualizeValues;
end;


end.
